# (C)2018 Ingram Micro Inc. all Rights Reserve
from poaupdater import uPackaging, uSysDB, uUtil, uPEM

import logging

from oacleanup.utils.errors import CleanUpException

logger = logging.getLogger()


def get_host_ids_by_services(services):
    package_hosts = [uPackaging.getPackageHosts(service).values() for service in services]
    package_hosts = [item for sublist in package_hosts for subsublist in sublist for item in subsublist]

    return list(set(package_hosts))


def mark_hosts_physically_destroyed(host_ids, is_physically_destroyed):
    if not host_ids:
        logger.debug('There are no hosts to mark as detached.')
        return

    q = 'UPDATE hosts SET is_physically_destroyed=%s WHERE host_id IN %s'
    con = uSysDB.connect()
    cur = con.cursor()
    cur.execute(q, 'y' if is_physically_destroyed else 'n', tuple(host_ids))
    con.commit()

    if is_physically_destroyed:
        logger.debug('The hosts with these IDs are marked as decommissioned: %s.' %
                     ', '.join([str(host_id) for host_id in host_ids]))
    else:
        logger.debug('The hosts with these IDs are operating properly: %s.' %
                     ', '.join([str(host_id) for host_id in host_ids]))


def filter_hosts_by_status(host_ids, is_physically_destroyed):
    q = 'SELECT host_id FROM hosts WHERE is_physically_destroyed=%s AND host_id IN %s'
    con = uSysDB.connect()
    cur = con.cursor()
    cur.execute(q, 'y' if is_physically_destroyed else 'n', tuple(host_ids))
    return [x for x, in cur.fetchall()]


def is_pa_agent_started():
    try:
        uUtil.execCommand('service pa-agent status', [0])
        return True
    except Exception:
        return False


def restart_pa_agent():
    logger.info("Restarting the pa-agent service...")
    try:
        logger.debug("Stopping the pa-agent service...")
        uUtil.execCommand('service pa-agent stop', [0, 1, 123])
        logger.debug("The pa-agent service is stopped.")
    except Exception:
        raise CleanUpException('The pa-agent service cannot be stopped. You must restart it manually.')

    try:
        logger.debug("Starting the pa-agent service...")
        uUtil.execCommand('service pa-agent start')
        logger.debug("The pa-agent service is started.")
    except Exception:
        raise CleanUpException('The pa-agent service cannot be started. You must start it manually.')

    logger.info("The pa-agent service is restarted.")


def restart_mn():
    logger.info("Restarting MN...")
    uPEM.stopMN()
    uPEM.startMN()
    logger.info("MN is restarted.")
